@@ -2,7 +2,7 @@
 """beanstalkc - A beanstalkd Client Library for Python"""
 
 __license__ = '''
-Copyright (C) 2008-2012 Andreas Bolka
+Copyright (C) 2008-2014 Andreas Bolka
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 '''
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 import logging
 import socket
@@ -70,10 +70,18 @@ class Connection(object):
         """Close connection to server."""
         try:
             self._socket.sendall('quit\r\n')
+        except socket.error:
+            pass
+        try:
             self._socket.close()
         except socket.error:
             pass
 
+    def reconnect(self):
+        """Re-connect to server."""
+        self.close()
+        self.connect()
+
     def _interact(self, command, expected_ok, expected_err=[]):
         SocketError.wrap(self._socket.sendall, command)
         status, results = self._read_response()
@@ -125,7 +133,7 @@ class Connection(object):
         jid = self._interact_value(
                 'put %d %d %d %d\r\n%s\r\n' %
                     (priority, delay, ttr, len(body), body),
-                ['INSERTED', 'BURIED'], ['JOB_TOO_BIG'])
+                ['INSERTED'], ['JOB_TOO_BIG','BURIED','DRAINING'])
         return int(jid)
 
     def reserve(self, timeout=None):
@@ -149,6 +157,10 @@ class Connection(object):
         """Kick at most bound jobs into the ready queue."""
         return int(self._interact_value('kick %d\r\n' % bound, ['KICKED']))
 
+    def kick_job(self, jid):
+        """Kick a specific job into the ready queue."""
+        self._interact('kick-job %d\r\n' % jid, ['KICKED'], ['NOT_FOUND'])
+
     def peek(self, jid):
         """Peek at a job. Returns a Job, or None."""
         return self._interact_peek('peek %d\r\n' % jid)
@@ -170,7 +182,7 @@ class Connection(object):
         return self._interact_yaml('list-tubes\r\n', ['OK'])
 
     def using(self):
-        """Return a list of all tubes currently being used."""
+        """Return the tube currently being used."""
         return self._interact_value('list-tube-used\r\n', ['USING'])
 
     def use(self, name):
@@ -272,6 +284,10 @@ class Job(object):
             self.conn.bury(self.jid, priority or self._priority())
             self.reserved = False
 
+    def kick(self):
+        """Kick this job alive."""
+        self.conn.kick_job(self.jid)
+
     def touch(self):
         """Touch this reserved job, requesting more time to work on it before
         it expires."""
